Use update function to refit model and extract info such as coef, logLik and estfun.
.modelfit(model, data, coeffun = coef, weights, control, parm = NULL)A function returning a list of
coef.
logLik.
the model object.
Did the model converge?
estfun.
model object.
data.
function that takes the model object and returns the coefficients. Useful when coef() does not return all coefficients (e.g. survreg).
weights.
control options from ctree_control.
which parameters should be used for instability test?